@@ -13,8 +13,10 @@ module Peek
         @requests[request_id]
       end
 
-      def save
-        @requests[Peek.request_id] = Peek.results
+      def save(request_id)
+        return false if request_id.blank?
+
+        @requests[request_id] = Peek.results
       end
 
       def reset
